<?php
/**
 * The template for displaying the Slider
 *
 * @package Catch Themes
 * @subpackage Create Pro
 * @since Create 1.2 
 */

if( !function_exists( 'create_featured_slider' ) ) :
/**
 * Add slider.
 *
 * @uses action hook create_before_content.
 *
 * @since Create 1.2
 */
function create_featured_slider() {
	global $post, $wp_query;
	
	// get data value from options
	$enableslider	= get_theme_mod( 'featured_slider_option', create_get_default_theme_options( 'featured_slider_option' ) );
	$sliderselect	= get_theme_mod( 'featured_slider_type', create_get_default_theme_options( 'featured_slider_type' ) );

	// Get Page ID outside Loop
	$page_id = $wp_query->get_queried_object_id();

	// Front page displays in Reading Settings
	$page_for_posts = get_option('page_for_posts'); 
 
	if ( $enableslider == 'entire-site' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enableslider == 'homepage' ) ) {
		$featured_slide_transition_effect	= get_theme_mod( 'featured_slide_transition_effect', create_get_default_theme_options( 'featured_slide_transition_effect' ) );
		$featured_slide_transition_length	= get_theme_mod( 'featured_slide_transition_length', create_get_default_theme_options( 'featured_slide_transition_length' ) );
		$featured_slide_transition_delay	= get_theme_mod( 'featured_slide_transition_delay', create_get_default_theme_options( 'featured_slide_transition_delay' ) );
		$create_featured_slider = '
			<section id="feature-slider">
				<div class="wrapper">
					<div class="cycle-slideshow" 
					    data-cycle-log="false"
					    data-cycle-pause-on-hover="true"
					    data-cycle-swipe="true"
					    data-cycle-auto-height=container
					    data-cycle-fx="'. $featured_slide_transition_effect .'"
						data-cycle-speed="'. $featured_slide_transition_length * 1000 .'"
						data-cycle-timeout="'. $featured_slide_transition_delay * 1000 .'"
						data-cycle-slides="> article"
						>
					    
					    <!-- prev/next links -->
					    <div class="cycle-prev"></div>
					    <div class="cycle-next"></div>

					    <!-- empty element for pager links -->
    					<div class="cycle-pager"></div>';

						// Select Slider
						if ( $sliderselect == 'demo-featured-slider' && function_exists( 'create_demo_slider' ) ) {
							$create_featured_slider .=  create_demo_slider();
						}
						else {
							$create_featured_slider .=  create_page_slider();
						}

		$create_featured_slider .= '
					</div><!-- .cycle-slideshow -->
				</div><!-- .wrapper -->
			</section><!-- #feature-slider -->';
				
		echo $create_featured_slider;
	}
}
endif;
add_action( 'create_before_content', 'create_featured_slider', 10 );


if ( ! function_exists( 'create_demo_slider' ) ) :
/**
 * This function to display featured posts slider
 *
 * @get the data value from customizer options
 *
 * @since Create 1.2
 *
 */
function create_demo_slider() {
	$create_demo_slider ='
						<article class="post demo-image-1 hentry slides displayblock">
							<figure class="slider-image">
								<a title="Slider Image 1" href="'. esc_url( home_url( '/' ) ) .'">
									<img src="'.get_template_directory_uri().'/images/gallery/slider1-1200x514.jpg" class="wp-post-image" alt="Slider Image 1" title="Slider Image 1">
								</a>
							</figure>
							<div class="entry-container">
								<header class="entry-header">
									<h2 class="entry-title">
										<a title="Slider Image 1" href="#"><span>Slider Image 1</span></a>
									</h2>
									<div class="screen-reader-text"><span class="post-time">Posted on <time pubdate="" datetime="2014-08-16T10:56:23+00:00" class="entry-date updated">16 August, 2014</time></span><span class="post-author">By <span class="author vcard"><a rel="author" title="View all posts by Catch Themes" href="http://catchthemes.com/blog/" class="url fn n">Catch Themes</a></span></span></div>
								</header>
								<div class="entry-content">
									<p>Slider Image 1 Content</p>
								</div>   
							</div>             
						</article><!-- .slides --> 	
						
						<article class="post demo-image-2 hentry slides displaynone">
							<figure class="Slider Image 2">
								<a title="Slider Image 2" href="'. esc_url( home_url( '/' ) ) .'">
									<img src="'. get_template_directory_uri() . '/images/gallery/slider2-1200x514.jpg" class="wp-post-image" alt="Slider Image 2" title="Slider Image 2">
								</a>
							</figure>
							<div class="entry-container">
								<header class="entry-header">
									<h2 class="entry-title">
										<a title="Slider Image 2" href="#"><span>Slider Image 2</span></a>
									</h2>
									<div class="screen-reader-text"><span class="post-time">Posted on <time pubdate="" datetime="2014-08-16T10:56:23+00:00" class="entry-date updated">16 August, 2014</time></span><span class="post-author">By <span class="author vcard"><a rel="author" title="View all posts by Catch Themes" href="http://catchthemes.com/blog/" class="url fn n">Catch Themes</a></span></span></div>
								</header>
								<div class="entry-content">
									<p>Slider Image 2 Content</p>
								</div>   
							</div>             
						</article><!-- .slides --> ';
	return $create_demo_slider;
}
endif; // create_demo_slider

if ( ! function_exists( 'create_page_slider' ) ) :
/**
 * This function to display featured page slider
 *
 * @since Create 1.2
 */
function create_page_slider() {
	$quantity	= get_theme_mod( 'featured_slide_number', create_get_default_theme_options( 'featured_slide_number' ) );

    global $post;

    $create_page_slider = '';
    $number_of_page 	= 0; 		// for number of pages
	$page_list			= array();	// list of valid page ids

	//Get number of valid pages
	for( $i = 1; $i <= $quantity; $i++ ){
		if( get_theme_mod( 'featured_slider_page_' . $i ) && get_theme_mod( 'featured_slider_page_' . $i ) > 0 ){
			$number_of_page++;

			$page_list	=	array_merge( $page_list, array( get_theme_mod( 'featured_slider_page_' . $i ) ) );
		}

	}

	if ( !empty( $page_list ) && $number_of_page > 0 ) {
		$get_featured_posts = new WP_Query( array(
			'posts_per_page'	=> $quantity,
			'post_type'			=> 'page',
			'post__in'			=> $page_list,
			'orderby' 			=> 'post__in'
		));
		$i=0; 

		while ( $get_featured_posts->have_posts()) : $get_featured_posts->the_post(); $i++;
			$title_attribute = the_title_attribute( array( 'before' => __( 'Permalink to:', 'create' ), 'echo' => false ) );
			$excerpt = get_the_excerpt();
			if ( $i == 1 ) { $classes = 'page post-'.$post->ID.' hentry slides displayblock'; } else { $classes = 'page post-'.$post->ID.' hentry slides displaynone'; }
			$create_page_slider .= '
			<article class="'.$classes.'">
				<figure class="slider-image">';
				if ( has_post_thumbnail() ) {
					$create_page_slider .= '<a title="Permalink to '.the_title('','',false).'" href="' . get_permalink() . '">
						'. get_the_post_thumbnail( $post->ID, 'create_slider', array( 'title' => esc_attr( $title_attribute ), 'alt' => esc_attr( $title_attribute ), 'class'	=> 'attached-page-image' ) ).'
					</a>';
				}
				else {
					//Default value if there is no first image
					$create_image = '<img class="pngfix wp-post-image" src="'.get_template_directory_uri().'/images/gallery/no-featured-image-1200x514.jpg" >';
					
					//Get the first image in page, returns false if there is no image
					$create_first_image = create_get_first_image( $post->ID, 'medium', array( 'title' => esc_attr( $title_attribute ), 'alt' => esc_attr( $title_attribute ), 'class' => 'attached-page-image' ) );

					//Set value of image as first image if there is an image present in the page
					if ( '' != $create_first_image ) {
						$create_image =	$create_first_image;
					}

					$create_page_slider .= '<a title="Permalink to '.the_title('','',false).'" href="' . get_permalink() . '">
						'. $create_image .'
					</a>';
				}

				$create_page_slider .= '
				</figure><!-- .slider-image -->
				<div class="entry-container">
					<header class="entry-header">
						<h2 class="entry-title">
							<a title="Permalink to '.the_title('','',false).'" href="' . get_permalink() . '">'.the_title( '<span>','</span>', false ).'</a>
						</h2>
						<div class="screen-reader-text">'.create_page_post_meta().'</div>
					</header>';
					if( $excerpt !='') {
						$create_page_slider .= '<div class="entry-content">'. $excerpt.'</div>';
					}
					$create_page_slider .= '
				</div><!-- .entry-container -->
			</article><!-- .slides -->';
		endwhile; 

		wp_reset_query();
  	}
	return $create_page_slider;
}
endif; // create_page_slider